void init_menu ();
void about_dialog();
void help_dialog();
void exit_dialog();
void not_implemented ();
void check_menu(char *path, int state);
char *trx_get_mode_name(void);
